import { EventEmitter } from '../event';
/**
 * 실행된 browser 기준으로, visibilityChange event 에 맞는 vendorPrefix 반환
 * @memberof VisibilityChangeObserver
 * @export
 * @returns {String}
 */
export declare function getVendorPrefix(): string;
/**
 * getVendorPrefix 의 값
 * @constant
 * @memberof VisibilityChangeObserver
 * @type {String}
 */
export declare const VENDOR_PREFIX: string;
/**
 * browser 상의 visibilitychange event 명
 * @constant
 * @memberof VisibilityChangeObserver
 * @type {String}
 */
export declare const VISIBILITY_EVENT_NAME: string;
/**
 * browser 상의 visibility hidden 시점의 event 명
 * @constant
 * @memberof VisibilityChangeObserver
 * @type {String}
 */
export declare const HIDDEN_METHOD_NAME: string;
/**
 * VisibilityChange Event Types
 * @event VisibilityChangeObserver#VISIBILITY_EVENTS
 * @memberof VisibilityChangeObserver
 * @property {String} CHANGE - 변경 시점
 * @property {String} GET_STATUS - 현재 상태값 체크
 */
/**
 * @export
 * @readonly
 * @enum {VISIBILITY_EVENTS}
 */
export declare enum VISIBILITY_EVENTS {
    CHANGE = "VISIBILITY_CHANGE-EVENTS-CHANGE",
    GET_STATUS = "VISIBILITY_CHANGE-EVENTS-GET_STATUS"
}
/**
 * browser 의 visibility 변화를 감지
 * @export
 * @class VisibilityChangeObserver
 * @alias observer/VisibilityChangeObserver
 * @extends {EventEmitter}
 */
export declare class VisibilityChangeObserver extends EventEmitter {
    constructor();
    /**
     * visibilitychange event 명 반환
     * @static
     * @returns {String}
     * @memberof VisibilityChangeObserver
     */
    static visibilityEventName(): string;
    /**
     * visibility hidden event 명 반환
     * @static
     * @returns {String}
     * @memberof VisibilityChangeObserver
     */
    static hiddenMethodName(): string;
    /**
     * visibility change 지원 여부 반환
     * @static
     * @returns {boolean}
     * @memberof VisibilityChangeObserver
     */
    static isSupportVisibilityChange(): boolean;
    /**
     * @private
     * @memberof VisibilityChangeObserver
     */
    private onVisibilityChangeListener;
    /**
     * @private
     * @returns {Boolean}
     * @memberof VisibilityChangeObserver
     */
    private isHidden;
    /**
     * 현재 상태를 확인하는 메소드
     * @returns {VisibilityChangeObserver}
     * @memberof VisibilityChangeObserver
     * @fires VisibilityChangeObserver#VISIBILITY_EVENTS
     */
    getStatus(): VisibilityChangeObserver;
    /**
     * 이벤트 감지 설정
     * @returns {VisibilityChangeObserver}
     * @memberof VisibilityChangeObserver
     */
    attach(): VisibilityChangeObserver;
    /**
     * 이벤트 감지 해제
     * @returns {VisibilityChangeObserver}
     * @memberof VisibilityChangeObserver
     */
    detach(): VisibilityChangeObserver;
    /**
     * destory
     * @returns {VisibilityChangeObserver}
     * @memberof VisibilityChangeObserver
     */
    destroy(): VisibilityChangeObserver;
}
